@@ -145,13 +145,17 @@ pub fn write_file(xs: &CalcitItems) -> Result<Calcit, String> {
 
 /// calcit-js represents DateTime in f64
 pub fn parse_time(xs: &CalcitItems) -> Result<Calcit, String> {
-  match xs.get(0) {
-    Some(Calcit::Str(s)) => match DateTime::parse_from_rfc3339(s) {
+  match (xs.get(0), xs.get(1)) {
+    (Some(Calcit::Str(s)), None) => match DateTime::parse_from_rfc3339(s) {
       Ok(time) => Ok(Calcit::Number(time.timestamp_millis() as f64)),
       Err(e) => Err(format!("parse-time failed, {}", e)),
     },
-    Some(a) => Err(format!("parse-time expected 1 string, got: {}", a)),
-    None => Err(String::from("parse-time expected 1 string, got nothing")),
+    (Some(Calcit::Str(s)), Some(Calcit::Str(f))) => match DateTime::parse_from_str(s, f) {
+      Ok(time) => Ok(Calcit::Number(time.timestamp_millis() as f64)),
+      Err(e) => Err(format!("parse-time failed, {} {} {}", s, f, e)),
+    },
+    (Some(a), Some(b)) => Err(format!("parse-time expected 1 or 2 strings, got: {} {}", a, b)),
+    (a, b) => Err(format!("parse-time expected 1 or 2 strings, got {:?} {:?}", a, b)),
   }
 }
 
@@ -165,6 +169,10 @@ pub fn format_time(xs: &CalcitItems) -> Result<Calcit, String> {
       let time = Utc.timestamp((n.floor() / 1000.0) as i64, (n.fract() * 1_000_000.0) as u32);
       Ok(Calcit::Str(time.to_rfc3339()))
     }
+    (Some(Calcit::Number(n)), Some(Calcit::Str(f))) => {
+      let time = Utc.timestamp((n.floor() / 1000.0) as i64, (n.fract() * 1_000_000.0) as u32);
+      Ok(Calcit::Str(time.format(f).to_string()))
+    }
     (Some(Calcit::Number(_)), Some(a)) => Err(format!("format-time Rust does not support dynamic format: {}", a)),
     (Some(a), Some(b)) => Err(format!("format-time expected time and string, got: {} {}", a, b)),
     (a, b) => Err(format!("format-time expected time and string, got: {:?} {:?}", a, b)),
